/**---------------------------------------------------------------------**/
/** Programm: TS_output.sas                                             **/
/**    Project    : twostage                                            **/
/**    Author     : Schill, Seiler                                      **/
/**    Date       : 1999-09-22                                          **/
/**    Update     : 2012-08-16                                          **/
/**                                                                     **/
/**    Context    : sas-twophase-package                                **/
/**    Purpose    : Unified Screen Presentation of Two-Phase Procedures **/
/**    Method     : -                                                   **/
/**    Procs      : proc IML                                            **/
/**    Include    : -                                                   **/
/**    Input      : &dat_ein (result dataset)                           **/
/**    Output     : -                                                   **/
/**                                                                     **/
/**    Validation : -                                                   **/
/**    Status     :                                                     **/
/**    Doku       : documentation/TPDocu.pdf                            **/
/**    Reference  : Schill/Drescher (1997). Stats in Medicine           **/
/**---------------------------------------------------------------------**/

%MACRO TS_OUTPUT(DAT_EIN =zlrauf,
                DOKU_COR=1
               );

 *************************************************************************;
 * DAT_EIN : Name of result dataset ;
 *************************************************************************;
 * DOKU_COR: Output correlation matrix?  (0=no, 1=yes);
 *************************************************************************;

 %LET PRG_NAME=TS_output.sas;
 %LET TEXT=0;
 options nocenter;

 %LET VARS=;
 data &DAT_EIN;
 set  &DAT_EIN;
   if _time ^= "" then do;
     call symput("_PROGRAM",_program);
     call symput("_METHOD" ,_method);
     call symput("_SOURCE" ,_source);
     call symput("_REGRESS",_regress);
     call symput("_TIME",_time);
     call symput("VARS",symget("VARS")|| " " || compress(_parms));
   end; else do;
     call symput("VARS",symget("VARS")|| " " || compress(_parms));
   end;
 run;

 *title1 "Program: &PRG_NAME,";
 *title2 "         &_SOURCE-->&_PROGRAM-->&DAT_EIN";

 %LET NP=0;
 %DO %WHILE(%SCAN(&VARS,&NP+1)^=);
   %LET NP=%EVAL(&NP+1);
   %LET VAR&NP=%SCAN(&VARS,&NP);
 %END;

 proc iml;
   start input;
      use &DAT_EIN;
        read all var {_estim}  into estim;
        read all var {_parms}  into parms;
        read all var {_stderr} into stderr;
        %DO N=1 %TO &NP;
          read all var {&&VAR&N} into v&N;
        %END;
    close &DAT_EIN;
    COV = v1 %DO N=2 %TO &NP; || v&N %END;;
   finish input;


   start output;
    * two-phase covariances etc.;
       STD = Diag(stderr);
       COR = inv(std)`*COV*inv(std);

       * 95%-Confidence Interval of parameter;
       ci_l   = estim - 1.96*stderr;
       ci_u   = estim + 1.96*stderr;
       result = estim || stderr || ci_l || ci_u ;
       col={ "  Estimate " "Std. Error " "  Lower    " "  Upper  " };
       reset fw=12;

       print /"program:     &_PROGRAM",
              "execution:   &_TIME",
              "method:      &_METHOD",
              "TSwork file: &_SOURCE",
              "regressors:  &_REGRESS",
              "output file: &DAT_EIN",
       ;

       * Ausgabe auf Bildschirm;
       reset noname;
       print "    ****   Estimation of Logistic Two-Phase Data   ****",
             "                         &_METHOD",
             "                                         Asymptotic 95%  ",
             "                                      Confidence Interval",
             result[rowname=parms colname=col format=12.6],;
       reset name;

       %IF &DOKU_COR ne 0 %THEN %DO;
         print "    ****   Correlation Matrix of Two-Stage Parameters   ****";
         reset fw=9;
         %let pp= 11;              * Printpositionen pro Zeile;
         %let pos=&pp;
         %do %while(&np>&pos);
           %let pos1=%eval(&pos-&pp+1);
           corr_r=COR[1:&np,&pos1:&pos];
           col_pr={ %do i= &pos1 %to &pos; &&var&i %end; };
           reset noname;
           print corr_r[rowname=parms colname=col_pr format=9.4];
           reset name;
           %let pos=%eval(&pos+&pp);
         %end;
         %let pos1=%eval(&pos-&pp+1);
         corr_r=COR[1:&np,&pos1:&np];
         col_pr={ %do i= &pos1 %to &np; &&var&i %end; };
         reset noname;
         print corr_r[rowname=parms colname=col_pr format=9.4];
         reset name;
       %END;

   finish output;

   run input;
   run output;
 quit;

%MEND TS_OUTPUT;
