*** Clear Log and Output before running program ***;
dm 'clear log';dm 'clear output';
/**--------------------------------------------------------------------**/
/** Programm: ExampleHda.sas                                           **/
/**    Project    : attributable fractions from two-phase studies      **/
/**    Author     : Schill                                             **/
/**    Date       : 2013-12-04                                         **/
/**                                                                    **/
/**    Context    : adjusted attrib fractions from 2p-c-c-studies      **/
/**    Purpose    : Example with HdA data                              **/
/**    Method     :                                                    **/
/**    Procs      : IML                                                **/
/**    Include    : macro twophase (sas-twophase-package)              **/
/**    Include    : macro af2p     (sas-af2phase)                      **/
/**    Input      : HdA data                                           **/
/**    Output     : af       (result dataset)                          **/
/**                                                                    **/
/**    Validation :                                                    **/
/**    Status     :                                                    **/
/**    Doku       : AFDocu.pdf                                         **/
/**    Reference  : Wild et al. (2014) AJE                             **/
/**--------------------------------------------------------------------**/

options nodate nonumber nocenter ps=23 ls=156 notes mprint nomlogic;
%let prgname=ExampleHda.sas;
footnote1 "Prgm: &prgname, &sysdate";

*This is the path, where the macros of the twophase package are stored;
%let path_tp=%str(d:\esave\sas-twophase-package\macros);
%include "&path_tp.\twophase.sas";

*This is the path, where macro af2p is stored;
%let path_af=%str(d:\esave\sas-af2phase\macros);
%include "&path_af.\af2p.sas";

libname in  "d:\esave\sas-twophase-package\data";

data hda1;
        set in.hdac_ph1;
run;

data hda2;
        set in.hdac_ph2;
        SMOKE1=(SMOKE=1);
        SMOKE2=(SMOKE=2);
        SMOKE3=(SMOKE=3);
run;

title'HdA Data, Stratif. A (8 Strata)';

     %twophase(folder      =&path_tp,
               path_ph1    =hda1,
               path_ph2    =hda2,
               methods     =ml_em,
               compare     =1,
               outest      =1,
               caco        =case,
               svar        =strata,
               counts_ph1  =count,
               weights_ph2 =count,
               regr        =smoke1 smoke2 smoke3 fy,
               s1pr        =0);
run;
*title'HdA Data, Stratif. G (13 Strata)';
     *twophase(folder      =&path_tp,
               path_ph1    =in.hdacg_ph1,
               path_ph2    =in.hdacg_ph2,
               methods     =ml_em,
               compare     =1,
               outest      =1,
               caco        =case,
               svar        =stratg,
               counts_ph1  =count,
               weights_ph2 =count,
               regr        =smoke1 smoke2 smoke3 fy);
run;

%af2p(
       pathdesign=em_design,
       pathparm  =em_theta,
       pathfinal =em_final,
       pathout   =af1,
       regress   =smoke1 smoke2 smoke3 fy, /* original regressor */
       factor    =smoke1 smoke2 smoke3       ,
       nameF     =Smoking,
       study     =HdA,
       s1pr      =0);
%af2p(
       pathout   =af2,
       regress   =smoke1 smoke2 smoke3 fy,
       factor    =fy,
       nameF     =Asbestos exposure,
       study     =HdA,s1pr=1);
%af2p(
       pathout   =af3,
       regress   =smoke1 smoke2 smoke3 fy,
       factor    =fy  smoke1 smoke2 smoke3,
       nameF=Asbestos + Smoking,
       study     =HdA);

data af;set af1 af2 af3;
proc print data=af noobs label;
var namef af se_af cl_af cu_af factor;
run;
